# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DeployResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'method': 'str',
        'poll_url': 'str',
        'received_time': 'datetime'
    }

    attribute_map = {
        'message': 'message',
        'method': 'method',
        'poll_url': 'pollUrl',
        'received_time': 'receivedTime'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DeployResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._message = None
        self._method = None
        self._poll_url = None
        self._received_time = None
        self.discriminator = None

        setattr(self, "_{}".format('message'), kwargs.get('message', None))
        setattr(self, "_{}".format('method'), kwargs.get('method', None))
        setattr(self, "_{}".format('poll_url'), kwargs.get('poll_url', None))
        setattr(self, "_{}".format('received_time'), kwargs.get('received_time', None))

    @property
    def message(self):
        """Gets the message of this DeployResponse.  # noqa: E501


        :return: The message of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeployResponse.


        :param message: The message of this DeployResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def method(self):
        """Gets the method of this DeployResponse.  # noqa: E501


        :return: The method of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this DeployResponse.


        :param method: The method of this DeployResponse.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def poll_url(self):
        """Gets the poll_url of this DeployResponse.  # noqa: E501


        :return: The poll_url of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._poll_url

    @poll_url.setter
    def poll_url(self, poll_url):
        """Sets the poll_url of this DeployResponse.


        :param poll_url: The poll_url of this DeployResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and poll_url is None:
            raise ValueError("Invalid value for `poll_url`, must not be `None`")  # noqa: E501

        self._poll_url = poll_url

    @property
    def received_time(self):
        """Gets the received_time of this DeployResponse.  # noqa: E501


        :return: The received_time of this DeployResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._received_time

    @received_time.setter
    def received_time(self, received_time):
        """Sets the received_time of this DeployResponse.


        :param received_time: The received_time of this DeployResponse.  # noqa: E501
        :type: datetime
        """

        self._received_time = received_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeployResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeployResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeployResponse):
            return True

        return self.to_dict() != other.to_dict()
